"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t;
    return { next: verb(0), "throw": verb(1), "return": verb(2) };
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("power-assert");
var sinon = require("sinon");
var proxyquire = require("proxyquire");
var testing_1 = require("../testing");
var mongo_entity_1 = require("../mongo_entity");
var host = process.env.MONGODB_HOST || '127.0.0.1';
var port = process.env.MONGODB_PORT || 27017;
describe('entity', function () {
    it('contains connector and collection name', function () { return __awaiter(_this, void 0, void 0, function () {
        var connector, collectionName, entity;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, testing_1.getConnector()];
                case 1:
                    connector = _a.sent();
                    collectionName = 'name';
                    entity = new mongo_entity_1.default(connector, collectionName);
                    assert.equal(entity.collection.collectionName, collectionName);
                    assert.equal(entity.connector, connector);
                    assert.notEqual(entity.collection, null);
                    return [2 /*return*/];
            }
        });
    }); });
    it('is possible to initialise entity with custom cache', function () {
        var cache = { local: '' };
        var entity = new mongo_entity_1.default(null, 'name', cache);
        assert.equal(entity['_cache'], cache);
        var globalCache = { global: '1' };
        mongo_entity_1.default.DefaultCache = globalCache;
        var otherEntity = new mongo_entity_1.default(null, 'name');
        assert.equal(otherEntity['_cache'], globalCache);
        mongo_entity_1.default.DefaultCache = null;
    });
    describe('find', function () {
        it('can find a multiple record', function () { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) {
                            var find = sinon.spy(entity.collection, 'find');
                            var selector = {};
                            var fields = {};
                            var skip = 1;
                            var limit = 2;
                            var timeout = 1000;
                            entity.find(selector, fields, skip, limit, timeout);
                            assert(find.calledWithExactly(selector, fields, skip, limit, timeout));
                        })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe('findOne', function () {
        it('can find a single record', function () { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) {
                            var find = sinon.spy(entity.collection, 'find');
                            var selector = {};
                            var options = {};
                            entity.findOne(selector, options);
                            assert(find.calledWithExactly(selector, options));
                        })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe('findOneCachedById', function () {
        testing_1.itWithEntity('returns an item even when it was not previously found, but it wont search twice', function (entity) { return __awaiter(_this, void 0, void 0, function () {
            var findSpy, result, element;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        findSpy = sinon.spy(entity.collection, 'findOne');
                        return [4 /*yield*/, entity.findOneCachedById('1')];
                    case 1:
                        result = _a.sent();
                        assert.equal(result, null);
                        sinon.assert.calledOnce(findSpy);
                        return [4 /*yield*/, entity.findOneCachedById('1')];
                    case 2:
                        result = _a.sent();
                        assert.equal(result, null);
                        sinon.assert.calledOnce(findSpy);
                        element = { _id: '1' };
                        return [4 /*yield*/, entity.insertOne(element)];
                    case 3:
                        _a.sent();
                        return [4 /*yield*/, entity.findOneCachedById('1')];
                    case 4:
                        result = _a.sent();
                        assert.deepEqual(result, element);
                        sinon.assert.calledTwice(findSpy);
                        return [2 /*return*/];
                }
            });
        }); });
        testing_1.itWithEntity('can find and cache results of finding a single item', function (entity) { return __awaiter(_this, void 0, void 0, function () {
            var find, result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        find = sinon.spy(entity.collection, 'findOne');
                        return [4 /*yield*/, entity.findOne({ _id: '1' })];
                    case 1:
                        result = _a.sent();
                        return [4 /*yield*/, entity.findOne({ _id: '1' })];
                    case 2:
                        result = _a.sent();
                        assert.deepEqual(result, { _id: '1' });
                        assert(find.calledTwice);
                        find.reset();
                        return [4 /*yield*/, entity.findOneCachedById('1')];
                    case 3:
                        result = _a.sent();
                        return [4 /*yield*/, entity.findOneCachedById('1')];
                    case 4:
                        result = _a.sent();
                        assert(find.calledOnce);
                        return [2 /*return*/];
                }
            });
        }); }, {
            entities: [{
                    data: [{ _id: '1' }]
                }]
        });
        testing_1.itWithEntity('clears the related cache when a document is updated', function (entity) {
            return __awaiter(this, void 0, void 0, function () {
                var findSpy, cacheSpy, foo, bar, selector;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            findSpy = sinon.spy(entity.collection, 'findOne');
                            cacheSpy = sinon.spy(entity, 'clearUpdateCaches');
                            return [4 /*yield*/, entity.insertOne({ _id: '1', file: 'foo' })];
                        case 1:
                            _a.sent();
                            return [4 /*yield*/, entity.insertOne({ _id: '2', file: 'bar' })];
                        case 2:
                            _a.sent();
                            return [4 /*yield*/, entity.findOneCachedById('1')];
                        case 3:
                            foo = _a.sent();
                            return [4 /*yield*/, entity.findOneCachedById('2')];
                        case 4:
                            bar = _a.sent();
                            selector = { _id: '1' };
                            entity.updateOne(selector, { $set: { file: 'boo' } });
                            assert(cacheSpy.calledWith(selector));
                            findSpy.reset();
                            return [4 /*yield*/, entity.findOneCachedById('1')];
                        case 5:
                            foo = _a.sent();
                            assert.deepEqual(foo, { _id: '1', file: 'boo' });
                            assert(findSpy.calledOnce);
                            findSpy.reset();
                            return [4 /*yield*/, entity.findOneCachedById('2')];
                        case 6:
                            bar = _a.sent();
                            assert(findSpy.notCalled);
                            return [2 /*return*/];
                    }
                });
            });
        });
        testing_1.itWithEntity('clears all caches when a document is updated and selector is unknown', function (entity) {
            return __awaiter(this, void 0, void 0, function () {
                var foo, bar, findSpy;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, entity.findOneCachedById('1')];
                        case 1:
                            foo = _a.sent();
                            return [4 /*yield*/, entity.findOneCachedById('2')];
                        case 2:
                            bar = _a.sent();
                            entity.updateOne({ file: 'foo' }, { $set: { file: 'boo' } });
                            findSpy = sinon.spy(entity.collection, 'findOne');
                            return [4 /*yield*/, entity.findOneCachedById('1')];
                        case 3:
                            foo = _a.sent();
                            return [4 /*yield*/, entity.findOneCachedById('2')];
                        case 4:
                            bar = _a.sent();
                            assert(findSpy.calledTwice);
                            return [2 /*return*/];
                    }
                });
            });
        });
        testing_1.itWithEntity('findOneCached can filter returned results', function (entity) { return __awaiter(_this, void 0, void 0, function () {
            var result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, entity.insertOne({ _id: '00', a: '1', b: '2', c: '3' })];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, entity.findOneCachedById('00', { b: 1 })];
                    case 2:
                        result = _a.sent();
                        assert.deepEqual(result, { b: '2' });
                        return [2 /*return*/];
                }
            });
        }); });
        testing_1.itWithEntity('findOneCached returns null if entity does not exists', function (entity) { return __awaiter(_this, void 0, void 0, function () {
            var result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, entity.findOneCachedById('0')];
                    case 1:
                        result = _a.sent();
                        assert.deepEqual(result, null);
                        return [4 /*yield*/, entity.findOneCachedById('0', { field: 1 })];
                    case 2:
                        result = _a.sent();
                        assert.deepEqual(result, null);
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe('updates', function () {
        testing_1.itWithEntity('one', function (entity) {
            return __awaiter(this, void 0, void 0, function () {
                var stub, selector, modifier, properties;
                return __generator(this, function (_a) {
                    stub = sinon.stub(entity.collection, 'updateOne');
                    selector = {};
                    modifier = {};
                    properties = {};
                    entity.updateOne(selector, modifier, properties);
                    sinon.assert.calledWith(stub, selector, modifier, properties);
                    return [2 /*return*/];
                });
            });
        });
        testing_1.itWithEntity('many', function (entity) {
            return __awaiter(this, void 0, void 0, function () {
                var stub, selector, modifier, properties;
                return __generator(this, function (_a) {
                    stub = sinon.stub(entity.collection, 'updateMany');
                    selector = {};
                    modifier = {};
                    properties = {};
                    entity.updateMany(selector, modifier, properties);
                    sinon.assert.calledWith(stub, selector, modifier, properties);
                    return [2 /*return*/];
                });
            });
        });
    });
    describe('addCacheToOptions', function () {
        it('adds entitys cache to options', function () {
            var cache = { g: 1 };
            var entity = new mongo_entity_1.default(null, null, cache);
            var options = {};
            var res1 = entity.addCacheToOptions(options);
            assert.deepEqual(res1, { cacheMap: cache });
            var optionsWithCache = { cacheMap: {} };
            var res2 = entity.addCacheToOptions(optionsWithCache);
            assert.deepEqual(res2, optionsWithCache);
        });
    });
    describe('filter', function () {
        it('can filter objects properties', function () {
            var entity = new mongo_entity_1.default(null, null);
            var obj = { a: 1, b: 2, c: 3 };
            var resultWith = entity.filter(obj, { a: 1, c: 1 });
            assert.deepEqual(resultWith, { a: 1, c: 3 });
            var resultWithout = entity.filter(obj, { a: 0, c: 0 });
            assert.deepEqual(resultWithout, { b: 2 });
        });
        it('does not include undefined elements', function () {
            var entity = new mongo_entity_1.default(null, null);
            var obj = { a: 1, b: 2, c: 3 };
            var resultWith = entity.filter(obj, { a: 1, c: 1, d: 1 });
            assert.deepEqual(resultWith, { a: 1, c: 3 });
        });
        it('throws error when no filter is specified', function () {
            var entity = new mongo_entity_1.default(null, null);
            var obj = {};
            assert.throws(function () { return entity.filter(obj, {}); }, /You need to specify the selector!/);
        });
        it('throws error when you mix include exclude', function () {
            var entity = new mongo_entity_1.default(null, null);
            var obj = {};
            assert.throws(function () { return entity.filter(obj, { a: 1, b: 0 }); }, /You cannot combine include and exclude!/);
        });
    });
    describe('findManyCached', function () {
        it('can find and cache results of finding multiple items', function () { return __awaiter(_this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) { return __awaiter(_this, void 0, void 0, function () {
                            var find, result;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        entity.collection.insertOne({ _id: '1' });
                                        find = sinon.spy(entity.collection, 'find');
                                        return [4 /*yield*/, entity.findAllCached()];
                                    case 1:
                                        result = _a.sent();
                                        return [4 /*yield*/, entity.findAllCached()];
                                    case 2:
                                        result = _a.sent();
                                        assert.deepEqual(result, [{ _id: '1' }]);
                                        assert(find.calledOnce);
                                        return [2 /*return*/];
                                }
                            });
                        }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
        it('findManyCached can filter returned results', function () { return __awaiter(_this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) { return __awaiter(_this, void 0, void 0, function () {
                            var result;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4 /*yield*/, entity.insertMany([
                                            { _id: '00', a: '1', b: '2', c: '3' },
                                            { _id: '01', a: '1', b: '2', c: '3' }
                                        ])];
                                    case 1:
                                        _a.sent();
                                        return [4 /*yield*/, entity.findAllCached({ a: 1, c: 1 })];
                                    case 2:
                                        result = _a.sent();
                                        assert.deepEqual(result, [{ a: '1', c: '3' }, { a: '1', c: '3' }]);
                                        return [2 /*return*/];
                                }
                            });
                        }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
        it('clears the cache when a new document is inserted', function () {
            return __awaiter(this, void 0, void 0, function () {
                var _this = this;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) { return __awaiter(_this, void 0, void 0, function () {
                                var find, result;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            find = sinon.spy(entity.collection, 'find');
                                            entity.insertOne({ _id: '1' });
                                            return [4 /*yield*/, entity.findAllCached()];
                                        case 1:
                                            result = _a.sent();
                                            entity.insertOne({ _id: '2' });
                                            return [4 /*yield*/, entity.findAllCached()];
                                        case 2:
                                            result = _a.sent();
                                            assert(find.calledTwice);
                                            assert.deepEqual(result, [{ _id: '1' }, { _id: '2' }]);
                                            return [2 /*return*/];
                                    }
                                });
                            }); })];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe('delete', function () {
        it('can delete a single document', function () { return __awaiter(_this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) { return __awaiter(_this, void 0, void 0, function () {
                            var result;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4 /*yield*/, entity.insertOne({ _id: '00', a: '1', b: '2', c: '3' })];
                                    case 1:
                                        _a.sent();
                                        return [4 /*yield*/, entity.insertOne({ _id: '01', a: '1', b: '2', c: '3' })];
                                    case 2:
                                        _a.sent();
                                        return [4 /*yield*/, entity.findAllCached()];
                                    case 3:
                                        result = _a.sent();
                                        assert.equal(result.length, 2);
                                        return [4 /*yield*/, entity.deleteOne({ _id: '00' })];
                                    case 4:
                                        _a.sent();
                                        return [4 /*yield*/, entity.findAllCached()];
                                    case 5:
                                        result = _a.sent();
                                        assert.equal(result.length, 1);
                                        return [2 /*return*/];
                                }
                            });
                        }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
        it('can delete multiple documents', function () {
            return __awaiter(this, void 0, void 0, function () {
                var _this = this;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) { return __awaiter(_this, void 0, void 0, function () {
                                var result;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4 /*yield*/, entity.insertOne({ _id: '00', a: '1', b: '2', c: '3' })];
                                        case 1:
                                            _a.sent();
                                            return [4 /*yield*/, entity.insertOne({ _id: '01', a: '1', b: '2', c: '3' })];
                                        case 2:
                                            _a.sent();
                                            return [4 /*yield*/, entity.deleteMany()];
                                        case 3:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findAllCached()];
                                        case 4:
                                            result = _a.sent();
                                            assert.equal(result.length, 0);
                                            return [2 /*return*/];
                                    }
                                });
                            }); })];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe('dispose', function () {
        it('deletes all records', sinon.test(function () {
            var entity = new mongo_entity_1.default(null, 'name');
            var stub = this.stub(entity, 'deleteMany');
            entity.dispose();
            sinon.assert.calledWith(stub, {}, true);
        }));
    });
    describe('testing', function () {
        it('can execute test with multiple entities', function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, testing_1.withEntity(function (e1, e2, e3) {
                                assert(e1);
                                assert.equal(e1.collection.collectionName, 'e1');
                                assert(e2);
                                assert.equal(e2.collection.collectionName, 'e2');
                                assert(e3);
                                assert.equal(e3.collection.collectionName, 'e3');
                            }, { entities: [{ name: 'e1' }, { name: 'e2' }, { name: 'e3' }] })];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe('custom loaders', function () {
        it('throws error when selectorKeyFunction is not specified with updates', function () { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) {
                            assert.throws(function () { return entity.createLoader(function () { }, { clearOnUpdate: true }); }, /You need to provide cache key function to determine when cache needs to be updated/);
                        })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
        it('can create a new data-loader with a custom cache', function () {
            return __awaiter(this, void 0, void 0, function () {
                var _this = this;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, testing_1.withEntity(function (entity) { return __awaiter(_this, void 0, void 0, function () {
                                var records, loader, spy, a;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            records = [{ _id: 1, name: 'A' }, { _id: 2, name: 'B' }, { _id: 3, name: 'C' }];
                                            entity.insertMany(records);
                                            loader = entity.createLoader(function (name) {
                                                return entity.collection.findOne({ name: name });
                                            }, {
                                                cacheMap: new mongo_entity_1.LruCacheWrapper(2),
                                                clearOnInsert: true,
                                                clearOnUpdate: true,
                                                selectorKeyFn: function (a) { return a.name; }
                                            });
                                            spy = sinon.spy(entity.collection, 'findOne');
                                            return [4 /*yield*/, entity.findOneCached(loader, 'A')];
                                        case 1:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'A')];
                                        case 2:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'B')];
                                        case 3:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'B')];
                                        case 4:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'A')];
                                        case 5:
                                            _a.sent();
                                            sinon.assert.calledTwice(spy);
                                            spy.reset();
                                            return [4 /*yield*/, entity.updateOne({ _id: 1 }, { $set: { name: 'D' } })];
                                        case 6:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'A')];
                                        case 7:
                                            a = _a.sent();
                                            assert.equal(a, null);
                                            sinon.assert.calledOnce(spy);
                                            spy.reset();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'C')];
                                        case 8:
                                            _a.sent();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'A')];
                                        case 9:
                                            _a.sent();
                                            sinon.assert.calledOnce(spy);
                                            spy.reset();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'B')];
                                        case 10:
                                            _a.sent();
                                            sinon.assert.calledOnce(spy);
                                            spy.reset();
                                            return [4 /*yield*/, entity.findOneCached(loader, 'C')];
                                        case 11:
                                            _a.sent();
                                            sinon.assert.calledOnce(spy);
                                            return [2 /*return*/];
                                    }
                                });
                            }); })];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe('LruCacheWrapper', function () {
        it('maps lru-cache functions', sinon.test(function () {
            function cacheStub() {
                return {
                    get: sinon.stub(),
                    set: sinon.stub(),
                    reset: sinon.stub(),
                    has: sinon.stub(),
                    del: sinon.stub()
                };
            }
            var LruCacheWrapper = proxyquire('../mongo_entity', { 'lru-cache': cacheStub }).LruCacheWrapper;
            var cacheWrapper = new LruCacheWrapper();
            cacheWrapper.clear();
            sinon.assert.calledOnce(cacheWrapper.cache.reset);
            cacheWrapper.get();
            sinon.assert.calledOnce(cacheWrapper.cache.get);
            cacheWrapper.set();
            sinon.assert.calledOnce(cacheWrapper.cache.set);
            cacheWrapper.cache.has.returns(true);
            var positiveResult = cacheWrapper.delete('1');
            assert(positiveResult);
            sinon.assert.calledWith(cacheWrapper.cache.del, '1');
            cacheWrapper.cache.has.returns(false);
            var negativeResult = cacheWrapper.delete('1');
            assert.equal(negativeResult, false);
        }));
    });
});
